Spanish ECQ Palma de Mallorca, Spain May 19th 2007 22 players David Quiñonero-Santiago Crypt (12 cards, min=19, max=31, avg=6.33) ------------------------------------------ 3x Howler 8 ANI PRE SPI obf Ahrimane:2 3x Siamese, The 7 PRE SPI ani pro Ahrimane:2 3x Cynthia Ingold 6 SPI ani for pre Ahrimane:2 2x Juanita Santiago 4 ani pre spi Ahrimane:2 1x Nettie Hale 5 ani cel pre pro spi Ahrimane:2 Library (90 cards) Master (16; 1 trifle) 1x Animalism 3x Blood Doll 1x Channel 10 3x Direct Intervention 1x Fame 1x Guardian Angel 1x Heidelberg Castle, Germany 1x Powerbase: Montreal 1x Rack, The 1x Rebel 1x Smiling Jack, The Anarch 1x WMRH Talk Radio Action (10) 6x Enchant Kindred 4x Nose of the Hound Ally (2) 1x Carlton Van Wyk 1x Ossian Equipment (2) 1x Flak Jacket 1x Sire's Index Finger Retainer (13) 1x Mr. Winthrop 8x Murder of Crows 1x Owl Companion 3x Raven Spy Action Modifier/Combat (6) 6x Swiftness of the Stag Reaction (22) 4x Cats' Guidance 4x Falcon's Eye 2x Forced Awakening 4x On the Qui Vive 8x Speak with Spirits Combat (18) 5x Aid from Bats 2x Canine Horde 3x Carrion Crows 8x Pack Alpha Event (1) 1x Dragonbound